@@ -43,6 +43,7 @@
 
 #include <QPainter>
 #include <QTextStream>
+#include <QTimer>
 
 #if OXYGEN_HAVE_X11
 #include <QX11Info>
@@ -148,6 +149,11 @@ namespace Oxygen
         connect(s.data(), &KDecoration2::DecorationSettings::fontChanged, this, &Decoration::recalculateBorders);
         connect(s.data(), &KDecoration2::DecorationSettings::spacingChanged, this, &Decoration::recalculateBorders);
 
+        // buttons
+        connect(s.data(), &KDecoration2::DecorationSettings::spacingChanged, this, &Decoration::updateButtonsGeometryDelayed);
+        connect(s.data(), &KDecoration2::DecorationSettings::decorationButtonsLeftChanged, this, &Decoration::updateButtonsGeometryDelayed);
+        connect(s.data(), &KDecoration2::DecorationSettings::decorationButtonsRightChanged, this, &Decoration::updateButtonsGeometryDelayed);
+
         // full reconfiguration
         connect(s.data(), &KDecoration2::DecorationSettings::reconfigured, this, &Decoration::reconfigure);
         connect(s.data(), &KDecoration2::DecorationSettings::reconfigured, SettingsProvider::self(), &SettingsProvider::reconfigure, Qt::UniqueConnection );
@@ -334,6 +340,10 @@ namespace Oxygen
         updateButtonsGeometry();
     }
 
+    //________________________________________________________________
+    void Decoration::updateButtonsGeometryDelayed()
+    { QTimer::singleShot( 0, this, &Decoration::updateButtonsGeometry ); }
+
     //________________________________________________________________
     void Decoration::updateButtonsGeometry()
     {
@@ -397,6 +407,7 @@ namespace Oxygen
 
         }
 
+        update();
 
     }
 
