@@ -1,5 +1,5 @@
-#ifndef oxygenmenubar_datah
-#define oxygenmenubar_datah
+#ifndef oxygenmenubar_data_h
+#define oxygenmenubar_data_h
 
 //////////////////////////////////////////////////////////////////////////////
 // oxygenmenubardata.h
@@ -28,9 +28,10 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "oxygenanimationdata.h"
+#include "oxygen.h"
+
 #include <QMenuBar>
 #include <QBasicTimer>
-#include <QPointer>
 
 namespace Oxygen
 {
@@ -177,7 +178,7 @@ namespace Oxygen
         //@{
 
         //! guarded action pointer
-        typedef QPointer<QAction> ActionPointer;
+        typedef WeakPointer<QAction> ActionPointer;
 
         //! current action
         virtual const ActionPointer& currentAction( void ) const
@@ -364,7 +365,7 @@ namespace Oxygen
         //@{
 
         //! guarded action pointer
-        typedef QPointer<QAction> ActionPointer;
+        typedef WeakPointer<QAction> ActionPointer;
 
         //! current action
         virtual const ActionPointer& currentAction( void ) const
